% Analyze the data generated by bulbpiri.m. Generate corresponding figures.
% Edited by John Meng, 02/23/2021. Contact: John.Meng@nyu.edu

clear;

close all
run_num_for_saving_figs=1000;    % The index of the run.
RealStim=1;   % Real stimulus for 1, have sorted index. Otherwise use original index.

set(0,'defaultUicontrolFontName','Adobe Caslon Pro')
set(0,'defaultUicontrolFontSize',24)
set(0,'defaultfigurecolor',[1 1 1])

ipar=01;
N_mitral= 240;

checki=1;checkj=2; TotalProb=4;
checkregion=[1,3009];

syn_age_thr=1;

thresh_frac_responsive=0.4; % highest fractional threshold for cell to be called responsive
thresh_frac_divergent=0.4; % highest fractional threshold for cell to be called diverent
thr_res_vec=thresh_frac_responsive/8:thresh_frac_responsive/8:thresh_frac_responsive;
thr_div_vec=thresh_frac_divergent/8:thresh_frac_divergent/8:thresh_frac_divergent;

file_tag= strcat('R',num2str(run_num_for_saving_figs),'_l',num2str(ipar,'%02i'));  % for local

file_loc=['Saved_Research/',file_tag];

Path_state= dir([file_loc,'/states_',file_tag,'.mat']); 

Path_para= dir([file_loc,'/para_',file_tag,'.mat']); 
load([Path_state.folder,'/',Path_state.name])

load([Path_para.folder,'/',Path_para.name])


[n_times,dataSize]=size(state);
time_axis=nan(n_times,1);
McActT=nan(N_mitral,TotalProb+1,n_times);   % save the first two odor activity. May change later.
y_fisher=nan(n_times,4);
Ref_step=6;


SynNumVec=nan(n_times,1);
GcActNumVec=nan(n_times,1);
fisher_vec=nan(n_times,1);
fisher_mat=nan(N_mitral,n_times);
fisher_indmat=nan(N_mitral,n_times);

res_num=zeros(TotalProb,8,n_times);
res_num_pair=zeros(8,n_times);
div_num=zeros(8,n_times);
res_id=zeros(N_mitral,2,8,n_times);
res_id_pair=zeros(N_mitral,8,n_times);
div_id=zeros(N_mitral,8,n_times);
corr_vec=zeros(1,n_times);

x0=400;    y0=400;
width=400;    height=300;



for i_time=1:n_times    % Main loop to analyze the saved data points.
    time=state{i_time,1};
    Mc_act=state{i_time,2};
    Gc_act=state{i_time,3};
    odor_nums=size(Mc_act,2);
    Syn_age=state{i_time,7};
    Syn_res=state{i_time,8};
    Mc_prob=state{i_time,5};
    %         Gc_prob=state{i_time,6};
    prob_nums=size(Mc_prob,2);

    time_axis(i_time)=time;

    McActT(:,:,i_time)=Mc_prob;
    Mc_back=repmat(Mc_prob(:,end),1,prob_nums);
    Mc_change=Mc_prob-Mc_back;

    for i_thr=1:8
        Mc_res_temp=(Mc_change >thr_res_vec(i_thr));
        res_num(:,i_thr,i_time)=sum(Mc_res_temp(:,1:TotalProb));
        res_id(:,1:TotalProb,i_thr,i_time)=Mc_res_temp(:,1:TotalProb);

        if prob_nums>=2
            Mc_div_temp=abs(Mc_prob(:,checki)-Mc_prob(:,checkj))>thr_div_vec(i_thr);
            div_num(i_thr,i_time)=sum(Mc_div_temp);
            div_id(:,i_thr,i_time)=Mc_div_temp;

        end
        Mc_res_pair= (Mc_res_temp(:,checki)+Mc_res_temp(:,checkj)+Mc_div_temp)>=1;
        res_num_pair(i_thr,i_time)=sum(Mc_res_pair);
        res_id_pair(:,i_thr,i_time)=Mc_res_pair;


    end
    % Calculation of fisher/d-prime and correlation.
    m1=Mc_prob(1:N_mitral,checki);
    m2=Mc_prob(1:N_mitral,checkj);

    fisher_thresh=0.;   %0.2;
    m1=max(m1,0); m2=max(m2,0);
    Dm = m2-m1;
    Sm = m1+m2;

    m_max=max([m1;m2]);
    % Calculate d-prime
    indices= abs(Dm)>thr_div_vec(1);

    J_ind=(indices>0);

    J_comp=zeros(length(m1),1);
    J_comp(indices)=sqrt(Dm(indices).^2./Sm(indices));
    J=mean(J_comp);

    % These two lines are for fisher
    %         J_comp(indices)=Dm(indices).^2./Sm(indices);
    %         J=sum(J_comp);

    % Should call it d-prime
    fisher_vec(i_time)=J;
    fisher_mat(:,i_time)=J_comp;
    fisher_indmat(:,i_time)=J_ind;

    temp= corrcoef(Mc_prob(1:N_mitral,checki),Mc_prob(1:N_mitral,checkj));
    corr_vec(i_time)=temp(1,2);

    Wmg=state{i_time,4}+0;
    SynNumVec(i_time)=sum(sum(Wmg));

end

width=1000;
figlab1=figure(1);   % Stats for Responsive and Divergent cell
set(gcf,'units','points','position',[x0,y0,width-200,height/2])
for i_thr=1:4
    subplot(1,4,i_thr)
    plt1=plot(time_axis-1509,div_num(i_thr+2,:)/N_mitral,'m',time_axis-1509,res_num_pair(i_thr+2,:)/N_mitral,'k');
    set(plt1,'linewidth',3)
    set(gca,'fontsize',12)

    %         xlabel('time')
    %         ylabel('number')
    %             if i_thr==1
    % %                 title(['Res & Div Num thr=',num2str(thr_res_vec(i_thr))])
    %             else
    title(['\theta=',num2str(thr_res_vec(i_thr+2))],'fontsize',12,'fontweight','normal')
    %             end
    %                 xlim(checkregion);
    %                 ylim([0,80]);
    xlim([0 1500])
    ylim([0 0.6])

end
figname= 'aRes&Div_numfrac';
file_name= strcat(figname,'_',file_tag,'.fig');
hgsave(figlab1,file_name)


figlab7=figure(2);  % d-prime
clf;

plt1=plot(time_axis-1509,fisher_vec,'k');
% plt1=plot(time_axis-9,fisher_vec,'k');

xlim([0 1500])
set(plt1,'linewidth',5)
% title('corr over time')
% legend('correlation','fisher')
set(gcf,'units','points','position',[x0+200,y0-200,height,height])
set(gca,'fontsize',18)


cd('../../')

time1=4; time2=64; time3=115;   % Tasks with pre-training
%       time1=1; time2=4; time3=63;  % Tasks without pre-training

%     Time_check_vec=[1510,3000];
Time_check_vec=[10,3009];

S_train1= state{time1,9};
S_train2= state{time2,9};
checki=1; checkj=2; TotalProb=4;

x0=400;    y0=400;
width=400;    height=300;

S_dif= S_train2(:,1)-S_train2(:,2);
S_dif_tanh=tanh(S_train2(:,1))-tanh(S_train2(:,2));
%     [~,Mc_sort_ind]=sort(S_train2(:,1)-S_train2(:,2));
Mc_sort_ind=  1:N_mitral;

figure(3)   % Stimulus 1 over stimulus 2
plt1=plot(S_train2(Mc_sort_ind,1),S_train2(Mc_sort_ind,2),'.k');
set(gca,'fontname','Adobe Caslon Pro','fontsize',24)
set(gcf,'units','points','position',[x0-100,y0,width,height])


figure(4)  % plot the stimuli.
clf
axes1=axes('fontname','Adobe Caslon Pro','fontsize',24);
plt1=plot(1:N_mitral,S_train2(Mc_sort_ind,1),1:N_mitral,S_train2(Mc_sort_ind,2));
ylim([0,2.5])
xlim([0 240])
%    lgd= legend('task1 odor1','task2 odor2');
set(plt1,'linewidth',5)
%    set(lgd,'fontsize',15,'fontname','Adobe Caslon Pro')
set(gcf,'units','points','position',[x0-100,y0,width,height])
%    set(gcf,'units','points','position',[x0-100,y0,width,height])



figure(11)  % Mc_act at time1

clf;
i_time=time1;
Mc_prob=state{i_time,5}(:,[checki,checkj,5]);

hold all
plot(1:N_mitral,Mc_prob(:,3),'color',[0.5,0.5,0.5],'linewidth',5)
plot(1:N_mitral,Mc_prob(:,1),'b','linewidth',5)
plot(1:N_mitral,Mc_prob(:,2),'color',[0,0.5,0],'linewidth',5);

ylim([0 1])
xlim([0 240])
set(gcf,'units','points','position',[x0,y0-100,width*0.75,height*0.75])
set(gca,'fontsize',20)
box on

figure(12)  % Mc_act at time2

clf;
i_time=time2;
Mc_prob=state{i_time,5}(:,[checki,checkj,5]);
hold all
plot(1:N_mitral,Mc_prob(:,3),'color',[0.5,0.5,0.5],'linewidth',5)
plot(1:N_mitral,Mc_prob(:,1),'b','linewidth',5)
plot(1:N_mitral,Mc_prob(:,2),'color',[0,0.5,0],'linewidth',5);

ylim([0 1])
xlim([0 240])
set(gcf,'units','points','position',[x0+100,y0-100,width*0.75,height*0.75])
set(gca,'fontsize',20)
box on

figure(13)  % Mc_act at time3
clf;
i_time=time3;
Mc_prob=state{i_time,5}(:,[checki,checkj,5]);
hold all
plot(1:N_mitral,Mc_prob(:,3),'color',[0.5,0.5,0.5],'linewidth',5)
plot(1:N_mitral,Mc_prob(:,1),'b','linewidth',5)
plot(1:N_mitral,Mc_prob(:,2),'color',[0,0.5,0],'linewidth',5);

ylim([0 1])
xlim([0 240])
set(gcf,'units','points','position',[x0+200,y0-100,width*0.75,height*0.75])
set(gca,'fontsize',20)
box on



figure(5)  % Mc_act dif
i_time=time2;
Mc_prob1=state{i_time,5}(:,[checki,checkj,5]);
Mc_diff1=Mc_prob1(:,1)-Mc_prob1(:,2);

i_time=time3;
Mc_prob2=state{i_time,5}(:,[checki,checkj,5]);
Mc_diff2=Mc_prob2(:,1)-Mc_prob2(:,2);

clf;
hold all
plot(1:N_mitral,S_dif(Mc_sort_ind),'color',[0.5,0.5,0.5],'linewidth',3)
plt1=plot(1:N_mitral,Mc_diff1(Mc_sort_ind),'k',1:N_mitral,Mc_diff2(Mc_sort_ind),'r');
xlim([0 240])
ylim([-0.5 0.5])
legend('stimuli dif.','time 0','time end','fontname','adobe caslon pro')
set(plt1,'linewidth',3)
set(gcf,'units','points','position',[x0-200,y0-300,width*0.75,height*0.75])
set(gca,'fontsize',18)
box on




figure(23)   % Wmg at time3
clf;
i_time=time3;
Wmg=state{i_time,4};
[~,Sort_con_num]=sort(sum(Wmg,1));

plt1=imagesc(Wmg(Mc_sort_ind,Sort_con_num)');
colormap('gray')
set(gcf,'units','points','position',[x0+100,y0-200,width/2,height/2])
set(gca,'fontsize',15)

figure(21)  % Wmg at time1
clf;
i_time=time1;
Wmg=state{i_time,4};
%     [~,Sort_con_num]=sort(sum(Wmg,1));
axes1=axes('fontname','Adobe Caslon Pro','fontsize',15);

plt1=imagesc(Wmg(Mc_sort_ind,Sort_con_num)');
colormap('gray')
set(gcf,'units','points','position',[x0-100,y0-200,width/2,height/2])
set(gca,'fontsize',15)

figure(22)    % Wmg at time2
clf;
i_time=time2;
Gc_act=state{i_time,3};        Wmg=state{i_time,4};
%     [~,Sort_con_num]=sort(sum(Wmg,1));

imagesc(Wmg(Mc_sort_ind,Sort_con_num)');
colormap('gray')
set(gcf,'units','points','position',[x0,y0-200,width/2,height/2])
set(gca,'fontsize',15)





figure(31)  % Wmm at time1
clf;
i_time=time1;
Wmg=state{i_time,4};

Wmm_plot= Wmg*Wmg';

plt1=imagesc(Wmm_plot(Mc_sort_ind,Mc_sort_ind)-diag(diag(Wmm_plot(Mc_sort_ind,Mc_sort_ind))));

axis square;
colorbar

set(gcf,'units','points','position',[x0-100,y0-400,width/2+50,height/2])
set(gca,'fontsize',15)
%     colormap('jet')
caxis([0 275])

figure(32)   % Wmm at time2
clf;
i_time=time2;
Wmg=state{i_time,4};

Wmm_plot= Wmg*Wmg';
plt1=imagesc(Wmm_plot(Mc_sort_ind,Mc_sort_ind)-diag(diag(Wmm_plot(Mc_sort_ind,Mc_sort_ind))));

axis square;
colorbar
%     colormap('jet')
caxis([0 275])
set(gcf,'units','points','position',[x0,y0-400,width/2+50,height/2])
set(gca,'fontsize',15)

figure(33)  % Wmm at time3
clf;
i_time=time3;
Wmg=state{i_time,4};

Wmm_plot= Wmg*Wmg';
plt1=imagesc(Wmm_plot(Mc_sort_ind,Mc_sort_ind)-diag(diag(Wmm_plot(Mc_sort_ind,Mc_sort_ind))));
axis square;
colorbar
set(gcf,'units','points','position',[x0+100,y0-400,width/2+50,height/2])
set(gca,'fontsize',15)
%     colormap('jet')
caxis([0 275])







